@@ -12,8 +12,8 @@ class FirstWindow:
         # Layout
 
         layout_header = [
-            [sg.Image(os.path.abspath('./doc/logo.png'))],
-            [sg.Text('Tiago Rodrigues (Tiago.Rodrigues@sectra.com)\nSECTRA - CO Iberia', justification='c')],
+            [sg.Image(os.path.abspath('../lib/site-packages/mllp_https_gui/doc/logo.png'))],
+            [sg.Text('Tiago Rodrigues (Tiago.Rodrigues@sectra.com)', justification='c')],
         ]
 
         layout_body = [
@@ -22,7 +22,7 @@ class FirstWindow:
         ]
 
         layout_footer = [
-            [sg.Image(os.path.abspath('./doc/sectra.png'))],
+            [],
         ]
 
         layout = [
@@ -46,7 +46,7 @@ class FirstWindow:
         self.firstwindow = sg.Window(
             'Choose Program',
             element_justification='c',
-            icon=os.path.abspath('./doc/icon.ico'),
+            icon=os.path.abspath('../lib/site-packages/mllp_https_gui/doc/icon.ico'),
         ).layout(layout)
 
 
