@@ -16,7 +16,7 @@ class LoadingWindow:
 
         layout_header = [
             [sg.Image(os.path.abspath('../lib/site-packages/mllp_https_gui/doc/logo.png'))],
-            [sg.Text('Tiago Rodrigues (Tiago.Rodrigues@sectra.com)\nSECTRA - CO Iberia', justification='c')],
+            [sg.Text('Tiago Rodrigues (Tiago.Rodrigues@sectra.com)', justification='c')],
         ]
 
         layout_body = [
