@@ -2,8 +2,6 @@
 ### By Tiago Rodrigues
 ### Sectra Iberia, Dec 2022
 import argparse
-import os
-import sysconfig
 
 from mllp_https_gui.gui import Gui
 from mllp_https_gui.loading_window import LoadingWindow
@@ -15,7 +13,6 @@ class ArgumentFormatter(
     pass
 
 
-
 def gui():
     Gui()
 
